# coding: utf-8

"""
    Mentortools Marketplace Server

    Mentortools service for ingesting payment-provider webhooks into normalized order events

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from marketplace_server_connector.api.catalog_api import CatalogApi  # noqa: E501


class TestCatalogApi(unittest.IsolatedAsyncioTestCase):
    """CatalogApi unit test stubs"""

    async def asyncSetUp(self) -> None:
        self.api = CatalogApi()

    async def asyncTearDown(self) -> None:
        await self.api.api_client.close()

    async def test_count_products_v1_catalog_products_count_get(self) -> None:
        """Test case for count_products_v1_catalog_products_count_get

        Count the portal's marketplace products  # noqa: E501
        """
        pass

    async def test_create_account_v1_catalog_accounts_post(self) -> None:
        """Test case for create_account_v1_catalog_accounts_post

        Connect a provider account  # noqa: E501
        """
        pass

    async def test_create_product_v1_catalog_products_post(self) -> None:
        """Test case for create_product_v1_catalog_products_post

        Register a marketplace product  # noqa: E501
        """
        pass

    async def test_list_products_v1_catalog_products_get(self) -> None:
        """Test case for list_products_v1_catalog_products_get

        List the portal's marketplace products (paginated)  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
