# coding: utf-8

"""
    Mentortools Marketplace Server

    Mentortools service for ingesting payment-provider webhooks into normalized order events

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel, Field, StrictBool
from marketplace_server_connector.models.id_out import IdOut

class WrappedResponseIdOut(BaseModel):
    """
    WrappedResponseIdOut
    """
    done: Optional[StrictBool] = True
    result: IdOut = Field(...)
    __properties = ["done", "result"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> WrappedResponseIdOut:
        """Create an instance of WrappedResponseIdOut from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of result
        if self.result:
            _dict['result'] = self.result.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> WrappedResponseIdOut:
        """Create an instance of WrappedResponseIdOut from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return WrappedResponseIdOut.parse_obj(obj)

        _obj = WrappedResponseIdOut.parse_obj({
            "done": obj.get("done") if obj.get("done") is not None else True,
            "result": IdOut.from_dict(obj.get("result")) if obj.get("result") is not None else None
        })
        return _obj


